package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.OrderSoundLog;

/**
 * 录音临时文件Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface OrderSoundLogMapper 
{
    /**
     * 查询录音临时文件
     * 
     * @param id 录音临时文件主键
     * @return 录音临时文件
     */
    public OrderSoundLog selectOrderSoundLogById(Integer id);


    public int selectCountOrderSoundLogByoId(Long id);


    /**
     * 查询录音临时文件列表
     * 
     * @param orderSoundLog 录音临时文件
     * @return 录音临时文件集合
     */
    public List<OrderSoundLog> selectOrderSoundLogList(OrderSoundLog orderSoundLog);

    /**
     * 新增录音临时文件
     * 
     * @param orderSoundLog 录音临时文件
     * @return 结果
     */
    public int insertOrderSoundLog(OrderSoundLog orderSoundLog);

    /**
     * 修改录音临时文件
     * 
     * @param orderSoundLog 录音临时文件
     * @return 结果
     */
    public int updateOrderSoundLog(OrderSoundLog orderSoundLog);

    /**
     * 删除录音临时文件
     * 
     * @param id 录音临时文件主键
     * @return 结果
     */
    public int deleteOrderSoundLogById(Integer id);

    /**
     * 批量删除录音临时文件
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderSoundLogByIds(Integer[] ids);
}
